class AlertRulesController < ApplicationController
  model_data_store(AlertRule)

  def before_set_target
    AlertRule.preload(:alert_rule_targets)
  end

  def before_set_targets
    AlertRule.preload(:alert_rule_targets)
  end

  def create
    model_ps = model_params
    alert_recipient_ps = alert_recipient_params
    @model = AlertRule.new_alert_model(model_ps[:type])

    @model.set_data(model_ps)
    @model.update_targets(model_ps[:alert_targets])
    @model.add_shifts(alert_recipient_ps[:alert_recipients_to_add])

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: :create,
        timestamp: Time.now.to_i
      }
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def update
    params = model_params
    alert_recipient_ps = alert_recipient_params

    @model.set_data(params)
    @model.update_targets(params[:alert_targets])
    @model.add_shifts(alert_recipient_ps[:alert_recipients_to_add])

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: :update,
        timestamp: Time.now.to_i
      }
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  private

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:alert_rule).permit(:name, :description, :enabled, :email_subject, :email_body, :type, :parameters, alert_targets: [])
  end

  def alert_recipient_params
    params.require(:alert_rule).permit(alert_recipients_to_add: [:shift_id, alert_recipients: []])
  end
end