class AlertsController < ApplicationController
  def self.set_target_before
    super + [:acknowledge]
  end

  model_data_store(Alert, {read: false, update: false, index: true, create: false}, {read: true, update: false, index: true, create: false})
  also_protect_with([RxModule::Authorization.verb("acknowledge", "Acknowledge", :acknowledge)])

  def before_set_targets
    @models = Alert.where(acknowledged: false).order(created_at: :desc)
  end

  def acknowledge
    params = acknowledge_params
    @model.acknowledged = true
    @model.acknowledged_by = params[:acknowledge_by]

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: :update,
        timestamp: Time.now.to_i
      }
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  private

  def acknowledge_params
    params.require(:alert).permit(:acknowledge_by)
  end
end
