import React from "react";
import {IconButton} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCheck} from "@rx-suite/pro-solid-svg-icons";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {AlertModel, AlertStore} from "../../stores/AlertStore";
import {currentUserCan, CurrentUserModel, CurrentUserStore} from "@rx-suite/stores";

export type AlertAcknowledgeTableButtonProps = {
    model: AlertModel
}

export const AlertAcknowledgeTableButton: React.FunctionComponent<AlertAcknowledgeTableButtonProps> = ({ model }) => {
    const {enqueueSnackbar} = useSnackbar();

    const user = CurrentUserStore.selectedModel as unknown as CurrentUserModel;

    const handleOnClick = React.useCallback(async () => {
        try {
            await model.acknowledge(user.name);
            enqueueSnackbar(t`Alert successfully acknowledged.`, {variant: 'success'});
        } catch (e) {
            enqueueSnackbar(t`Failed to acknowledge alert.`, {variant: 'error'});
            console.error(e);
        }
    }, [model, user]);

    if(currentUserCan(AlertStore.permissionTarget as string, 'acknowledge')){
        return (
            <IconButton onClick={handleOnClick}>
                <FontAwesomeIcon icon={faCheck} color={'rgb(60,183,29)'}/>
            </IconButton>
        )
    }else{
        return null;
    }
}