import React, {useCallback, useEffect, useMemo, useState} from "react";
import {observer} from "mobx-react-lite";
import {SelectField, useModelContext, SelectFieldProps} from "@rx-suite/ui";
import {ValidationError} from "yup";
import { ParameterToSchemaConversion } from "../../pages/alert_rules/form/tabs/AlertRuleTriggerTab";
import { AlertRuleModel } from "../../stores/AlertRuleStore";

type ParameterSelectProps = {
    ruleModel: "MachineRemainsInStateRuleParameters";
    name: string;
    value?: () => string | number;
    onChange?: (n: string | undefined, value: any) => void
} & Omit<SelectFieldProps, 'onChange' | 'value'>

export const ParameterSelect: React.FunctionComponent<ParameterSelectProps> = observer(({
                                                                                           ruleModel, 
                                                                                           name, 
                                                                                           options, 
                                                                                           value, 
                                                                                           onChange,
                                                                                           ...props
                                                                                      }) => {
    const label = ParameterToSchemaConversion[ruleModel][name].label;
    const validation = ParameterToSchemaConversion[ruleModel][name].validation;

    const model = useModelContext() as AlertRuleModel;
    const [error, setError] = useState<string>('')

    const validate = () => {
        try {
            validation.validateSync(model.viewModel.parameters[name]);
            setError('');
        } catch (e) {
            if(!(e instanceof ValidationError)) {throw e}
            setError(e.message);
        }
    }

    useEffect(() => {
        validate();
    }, [])

    const handleChange = useCallback((n: string | undefined , value: any) => {
        if(onChange) {
            onChange(name, value);
        } else  {
            model.viewModel.parameters[name] = value;
        }
        validate();
    }, [model.viewModel.parameters, onChange, validate])

    const resolvedValue = () => {
        if(value) {return value;}
        return model.viewModel.parameters[name]
    }

    return <SelectField value={resolvedValue()}
                        options={options}
                        onChange={handleChange}
                        error={error !== ''}
                        helperText={error}
                        {...props}
    />
})