import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Switch, Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {useModelContext} from "@rx-suite/ui";

type ModelEnabledToggleSwitchProps = {
    label: string;
    enabledPropName: string;
    disabled?: boolean;
};

const useStyles = makeStyles((theme) => ({
    wrapper: {
        padding: '8px 32px',
        width: 'fit-content',
        border: 'solid 1px rgba(0, 0, 0, 0.12)',
        borderRadius: '4px'
    }
}));

export const ModelEnabledToggleSwitch: React.FunctionComponent<ModelEnabledToggleSwitchProps> = observer(({label, enabledPropName, disabled=false}) => {
    const model = useModelContext();
    const classes = useStyles();

    const checked = model.viewModel.dig(enabledPropName);

    const setEnabled = React.useCallback((checked: boolean) => {
        model.nestedAssignment(enabledPropName, checked);
    }, [model]);

    return (
        <Grid container className={classes.wrapper} direction={'column'} justifyContent={'center'} alignItems={'center'}>
            <Typography variant={"h6"}>{label}</Typography>
            <Grid component="label" container justifyContent="center" alignItems="center" spacing={1}>
                <Grid item><Typography variant={"body1"}><Trans>Off</Trans></Typography></Grid>
                <Grid item>
                    <Switch disabled={disabled} checked={checked} onChange={(event) => { setEnabled(event.target.checked) }} name={enabledPropName} />
                </Grid>
                <Grid item><Typography variant={"body1"}><Trans>On</Trans></Typography></Grid>
            </Grid>
        </Grid>
    );
})
