import * as React from "react";
import {t} from "@lingui/macro";
import {UserPickerModel, UserPickerStore} from "@rx-suite/stores";
import {AlertingEmailStore} from "../stores/AlertingEmailStore";

const filterMethod: (user: UserPickerModel) => boolean = (user: UserPickerModel) => {
    return !!user.email;
}

const displayName = (user: UserPickerModel) => {
    if(!user.email){
        return `${user.name} (NO EMAIL)`;
    }
    return `${user.name} (${user.email})`;
}

export const useEmailRecipientOptions = () => {
    const opts = [] as { label: string, options: { label: string, value: string }[] }[];

    const sortedAlertingEmails = AlertingEmailStore.models.sort((a,b)=>  a.displayName.localeCompare(b.displayName));
    if(sortedAlertingEmails.length > 0){
        const group = {label: t`Alerting Emails`, options: [] as { label: string, value: string, disabled?: boolean }[] }
        sortedAlertingEmails.forEach(a => {
            group.options.push({label: a.displayName, value: `i-${a.id}`});
        })
        opts.push(group);
    }

    const group = {label: t`Rx-Hub Users`, options: [] as { label: string, value: string, disabled: boolean }[] };
    (UserPickerStore.getAll() as UserPickerModel[]).filter(filterMethod)
        .sort((a: UserPickerModel, b:UserPickerModel) =>  displayName(a).localeCompare(displayName(b)))
        .forEach((user: UserPickerModel) => {
            group.options.push({label: displayName(user), value: `e-${user.getId()}`, disabled: true});
        })
    opts.push(group);

    return opts;
}