import * as React from 'react';
import {observer} from "mobx-react-lite";
import {Conditional, FormProps, ModelForm, ModelInput, PaddedPaper} from "@rx-suite/ui";
import {t} from '@lingui/macro';
import {TabsContainer} from "../../../components/generic/TabsContainer";
import {AlertRuleRecipientTab} from "./tabs/AlertRuleRecipientTab";
import {AlertRuleTargetsTab} from "./tabs/AlertRuleTargetsTab";
import {AlertRuleTriggerTab} from "./tabs/AlertRuleTriggerTab";
import {AlertRuleEmailTab} from "./tabs/AlertRuleEmailTab";
import Box from "@material-ui/core/Box";
import {AlertRuleModel} from "../../../stores/AlertRuleStore";
import {ModelEnabledToggleSwitch} from "../../../components/generic/ModelEnabledToggleSwitch";

type MachineAlertRuleFormProps = {
    model: AlertRuleModel
} & Omit<FormProps, 'model'>

export const AlertRuleForm: React.FunctionComponent<MachineAlertRuleFormProps> = observer(({model}) => {
    return (
        <PaddedPaper>
            <ModelForm model={model} suppressMakeCopy suppressImportExport suppressWrapper>
                <Conditional condition={!model.isNew}>
                    <Box mt={0.5} mb={1.5}>
                        <ModelEnabledToggleSwitch
                            label={t`Alert Enabled`}
                            enabledPropName={'enabled'}
                        />
                    </Box>
                </Conditional>
                <ModelInput name={"name"}/>
                <ModelInput name={"description"}/>
                <Box mt={2}>
                    <TabsContainer
                        variant="scrollable"
                        scrollButtons="auto"
                        tabs={[
                            {
                                label: t`Alert Trigger`,
                                component: <AlertRuleTriggerTab/>,
                                defaultTab: true
                            },
                            {
                                label: t`Alert Message`,
                                component: <AlertRuleEmailTab/>,
                            },
                            {
                                label: t`Alert Recipients`,
                                component: <AlertRuleRecipientTab />
                            },
                            {
                                label: t`Machines to Monitor`,
                                component: <AlertRuleTargetsTab/>
                            }
                        ]}
                    />
                </Box>
            </ModelForm>
        </PaddedPaper>
    )
});
