import * as React from "react";
import {LinkButton, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {AlertingEmailStore} from "../../../../stores/AlertingEmailStore";
import {crossModuleLink, ShiftModel, ShiftStore, UserPickerStore} from "@rx-suite/stores";
import {observer} from "mobx-react-lite";
import {AssociatedModelTable} from "@rx-suite/ui";
import {AlertShiftModel, AlertShiftStore} from "../../../../stores/AlertShiftStore";
import {AlertRuleModel} from "../../../../stores/AlertRuleStore";
import {Typography} from "@material-ui/core";
import Box from "@material-ui/core/Box";
import {RuleRecipientsDialogForm} from "../../../../components/alert_rule/rule_recipients/RuleRecipientsDialogForm";
import {useEmailRecipientOptions} from "../../../../hooks/useAlertRecipientsOptions";
import {useMemo} from "react";
import {TextBadge} from "../../../../components/generic/TextBadge";
import {InlineWarning} from "../../../../components/generic/InlineWarning";

export const AlertRuleRecipientTab: React.FunctionComponent = observer(() => {
    AlertShiftStore.setLimit(5);

    AlertingEmailStore.getAll();
    UserPickerStore.getAll();

    const linkToShifts = crossModuleLink('rx_hub', '/shifts');

    const model = useModelContext() as AlertRuleModel;

    const columns = useMemo(() => {
        return [
            {
                Header: t`Shift`,
                accessor: (shift: ShiftModel) => shift,
                id: 'shift_id',
                sortable: false,
                Cell: (cellInfo: {value: AlertShiftModel}) => {
                    const shift = ShiftStore.models.find(s => s.id == cellInfo.value.shift_id)
                    const shiftName = shift ? shift.name : 'unknown';

                    return (
                        <span>{shiftName}</span>
                    )
                }
            },
            {
                Header: t`Recipients`,
                accessor: (shift: AlertShiftModel) => shift,
                id: 'alert_recipients',
                sortable: false,
                Cell: (cellInfo: {value: AlertShiftModel}) => {
                    const recipients = cellInfo.value.alert_recipients
                    const columnRecipients = useEmailRecipientOptions().map(opts =>
                        opts.options.filter(r =>
                            Object.values(recipients).includes(r.value)
                        )
                    ).flat();

                    return columnRecipients.map(recipients => (
                        <TextBadge text={recipients.label}/>
                    ));
                }
            }
        ]
    }, [ShiftStore.models, AlertingEmailStore.models]);

    if(!ShiftStore.isLoading && ShiftStore.models.length === 0){
        return (
            <Box>
                <InlineWarning text={t`There are no shifts currently configured. Alerts require one or more shift to be configured.`}/>
                {
                    linkToShifts &&
                    <Box mt={3} ml={6}>
                        <LinkButton
                            component={'a'}
                            to={linkToShifts}
                            color={'secondary'}
                            variant={'contained'}
                            size={'large'}
                        >
                            {t`Configure Shifts`}
                        </LinkButton>
                    </Box>
                }
            </Box>
        )
    }

    return (
        <React.Fragment>
            <Box mb={1}>
                <Typography variant={'caption'}>{t`Tip: alerts are only sent during active shifts. To disable this alert during quiet periods, ensure there are no shifts running at that time. `}</Typography>
            </Box>
            <AssociatedModelTable
                baseModel={model}
                columns={columns}
                store={AlertShiftStore}
                associatedColumnName={'alert_recipients_to_add'}
                DialogForm={RuleRecipientsDialogForm}
                dialogTitle={t`Add Shift Recipients`}
                fixedHeight={false}
                defaultFiltered={[{id: "alert_rule_id", value: model.getId()}]}
                noLinkColumns={['shift_id', 'alert_recipients']}
                replacementActions={
                    {
                        Read: () => null
                    }
                }
                suppressWrapper
            />
        </React.Fragment>
    )
});
