import * as React from "react";
import {ModelSelect} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {MachineGroupStore} from "../../../../stores/MachineGroupStore";
import {MachineStore} from "../../../../stores/MachineStore";
import {Typography} from "@material-ui/core";
import Box from "@material-ui/core/Box";
import {HintList} from "../../../../components/generic/HintList";
import {observer} from "mobx-react-lite";

export const AlertRuleTargetsTab: React.FunctionComponent = observer(() => {
    MachineStore.getAll();
    MachineGroupStore.getAll();

    const targetHints = [
        {key: "Machines", text: t`If the machine triggers the alert condition, an alert will be sent.`},
        {key: "Machine Groups", text: t`If any machine of the group triggers the alert condition, an alert will be sent.`}
    ]

    const selectOptions = React.useMemo(() => {
        const opts = [] as { label: string, options: { label: string, value: string }[] }[];

        const sortedGroups = MachineGroupStore.models.sort((a,b)=>  a.name.localeCompare(b.name));
        if(sortedGroups.length > 0){
            const group = {label: t`Machine Groups`, options:[]}
            sortedGroups.forEach(g => {
                group.options.push({label: g.name, value: `g-${g.id}`});
            })
            opts.push(group);
        }

        const sortedMachine = MachineStore.models.sort((a,b)=>  a.extendedName.localeCompare(b.extendedName));
        if(sortedMachine.length > 0){
            const group = {label: t`Machines`, options:[]}
            sortedMachine.forEach(m => {
                group.options.push({label: m.extendedName, value: `m-${m.id}`});
            })
            opts.push(group);
        }

        return opts;
    }, [MachineGroupStore.models, MachineStore.models]);

    return (
        <React.Fragment>
            <ModelSelect name={'alert_targets'}
                         options={selectOptions}
                         multiple
                         hint={
                             {
                                 title: t`Machines and Machine Groups to monitor`,
                                 children:
                                     <Box>
                                         <Box mb={0.5}>
                                             <Typography>{t`Determines which machine or machines groups are to be monitored for this alert.`}</Typography>
                                         </Box>
                                         <HintList hints={targetHints}/>
                                     </Box>
                             }
                         }
                         loading={MachineStore.isLoading || MachineGroupStore.isLoading}
            />
        </React.Fragment>
    )
});
