import * as React from "react";
import {SelectField, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {observer} from "mobx-react-lite";
import {useCallback} from "react";
import {MachineRemainsInStateTriggerParameters} from "../../../../components/alert_rule/rule_trigger_parameters/MachineRemainsInStateTriggerParameters";
import {AlertRuleModel, AlertType} from "../../../../stores/AlertRuleStore";
import Box from "@material-ui/core/Box";
import {Typography} from "@material-ui/core";
import {HintList} from "../../../../components/generic/HintList";
import {MachineRemainInStateSchema} from "../../../../objects/alert_rule_schema/MachineRemainsInStateSchema";

// When adding a new rule, this needs to be set to link the schema of the parameters to the parameters themselves
export const ParameterToSchemaConversion = {
    MachineRemainsInStateRuleParameters: MachineRemainInStateSchema,
    MachineTimeDeviationParameters: {}
}

export const AlertRuleTriggerTab: React.FunctionComponent = observer(() => {
    const model = useModelContext() as AlertRuleModel;

    const ruleTriggerOptions = [
        {label: t`Machine remains in state for duration`, value: 'MachineInState'},
        {label: t`Machine time deviates from server time`, value: 'MachineTimeDeviation'}
    ];

    const ruleHints = [
        {
            key: t`Machine remains in state for duration`,
            text: t`A machine stays in one of the selected state longer than the specified duration.`
        },
        {
            key: t`Machine time deviates from server time` ,
            text: t`A machine sends data with a time difference of 10 or more minutes to the server time.`
        },
    ]

    const AlertRuleRouting = useCallback(() => {
        switch (model.viewModel.type) {
            case 'MachineInState':
                return <MachineRemainsInStateTriggerParameters/>;
            case 'MachineTimeDeviation':
                return null;
        }
        throw 'InvalidReportTemplate'
    }, [model.viewModel.type])


    return (
        <React.Fragment>
            <SelectField
                onChange={(e, value) => model.changeAlertType(value as AlertType)}
                value={model.viewModel.type}
                options={ruleTriggerOptions}
                hint={
                    {
                        title: t`Alert Trigger`,
                        children:
                            <Box>
                                <Box mb={0.5}>
                                    <Typography>{t`Determines when an alert should be sent out.`}</Typography>
                                </Box>
                                <HintList hints={ruleHints}/>
                            </Box>
                    }
                }
            />
            {<AlertRuleRouting/>}
        </React.Fragment>
    )
});
