import * as React from 'react';
import {BreadModel, HintButton, makeColumn, PaddedPaper} from "@rx-suite/ui";
import {AlertingEmailStore} from "../../stores/AlertingEmailStore";
import {AlertingEmailForm} from "./AlertingEmailForm";
import {t, Trans} from "@lingui/macro";
import {createStyles, Grid, makeStyles, Theme, Typography} from "@material-ui/core";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        bold: {
            fontWeight: 'bold'
        }
    })
);

export const AlertingEmailBreadModel = () => {
    const classes = useStyles();

    const columns = [
        makeColumn('name', t`Name`, "string"),
        makeColumn('email', t`Email`, "string")
    ];

    return (
        <PaddedPaper>
            <Grid container alignItems={'center'}>
                <Typography variant={'caption'}><Trans>How are these emails different than user email addresses?</Trans></Typography>
                <HintButton title={t`Alerting Email Addresses`}>
                    <Trans>The email addresses defined here will <span className={classes.bold}>only</span> be used for alerting purposes. They will not provide the user with any login credentials.</Trans>
                </HintButton>
            </Grid>
            <BreadModel store={AlertingEmailStore} Form={AlertingEmailForm} columns={columns} tableProps={{suppressWrapper: true}}/>
        </PaddedPaper>
    )
};