import * as React from 'react';
import {observer} from "mobx-react-lite";
import {
    ButtonField,
    Conditional,
    FormProps,
    IfFalse,
    IfTrue,
    PaddedPaper
} from "@rx-suite/ui";
import {Box, Button, createStyles, Divider, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {Alert} from "@material-ui/lab";
import {useSnackbar} from "notistack";
import {AlertModel} from "../../stores/AlertStore";
import {CurrentUserModel, CurrentUserStore} from "@rx-suite/stores";
import {Check} from "@material-ui/icons";
import {grey} from "@material-ui/core/colors";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        emailBodyWrapper: {
            minHeight: '200px',
            border: `solid 1px ${grey[400]}`,
            borderRadius: '5px',
            padding: theme.spacing(1)
        }
    })
);

export type AlertFormProps = {
    model: AlertModel
} & Omit<FormProps, 'model'>

export const AlertForm: React.FunctionComponent<AlertFormProps> = observer(({model}) => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const user = CurrentUserStore.selectedModel as unknown as CurrentUserModel;

    const handleAcknowledge = React.useCallback(async () => {
        try {
            await model.acknowledge(user.name);
            enqueueSnackbar(t`Alert successfully acknowledged.`, {variant: 'success'});
        } catch (e) {
            enqueueSnackbar(t`Failed to acknowledge alert.`, {variant: 'error'});
            console.error(e);
        }
    }, [model, user]);

    return (
        <PaddedPaper>
            <Conditional condition={model.acknowledged as boolean}>
                <IfTrue>
                    <Alert severity="success">{t`This alert has been acknowledged by` + ` ${model.acknowledged_by}.`}</Alert>
                </IfTrue>
                <IfFalse>
                    <Alert severity="warning">{t`This alert has not yet been acknowledged.`}</Alert>
                    <Box mt={1}>
                        <ButtonField
                            text={t`Acknowledge`}
                            onClick={handleAcknowledge}
                            color={'secondary'}
                            variant={'contained'}
                            startIcon={<Check/>}
                        />
                    </Box>
                </IfFalse>
            </Conditional>
            <Box mt={1} mb={1}>
                <Divider/>
            </Box>
            <Box>
                <Typography variant={'h5'}>{model.alert_subject}</Typography>
                <Grid container>
                    <Box mr={0.5}>
                        <Typography>
                            {t`Sent to`+":"}
                        </Typography>
                    </Box>
                    <Typography>{model.sent_to}</Typography>
                </Grid>
                <Box mt={2} className={classes.emailBodyWrapper}>
                    <Typography>
                        {model.alert_body}
                    </Typography>
                </Box>
            </Box>
        </PaddedPaper>
    )
});
