import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";

@model({
    transportLayer: "/api/alert_shifts",
    permissionTarget: "MachineAlertRule",
    routingInfo: {
        create: "/settings/alert_shifts/create",
        read: "/settings/alert_shifts/:id/edit",
        update: "/settings/alert_shifts/:id/edit",
    }
})

export class AlertShiftModel extends Model {
    @attribute({
        label: t`Shift`,
        validation: yup.number().required().typeError(t`A shift for the alert recipients is required.`)
    })
    shift_id: number | null = null;

    @attribute({
        label: t`Recipients`,
        validation: yup.array().of(yup.string()).min(1, t`At least 1 alert recipient is required.`)
    })
    alert_recipients: string[] = [];

    @attribute({
        label: t`Alert Rule Id`,
        validation: yup.number()
    })
    alert_rule_id: number = 0

    constructor() {
        super();
        super.setup();
    }
}

export const AlertShiftStore = AlertShiftModel.store as DataStore<AlertShiftModel>;