import {attribute, DataStore, Model, model} from '@rx-suite/data';
import {t} from "@lingui/macro";
import {action} from "mobx";

@model({
    transportLayer: "/api/alerts",
    permissionTarget: "Alert",
    routingInfo: {
        read: '/alerts/:id/edit',
    }
})
export class AlertModel extends Model {
    @attribute({
        label: t`Alert Email Subject`,
    })
    alert_subject = '';

    @attribute({
        label: t`Alert Email Body`,
    })
    alert_body = '';

    @attribute({
        label: t`Alert Email Body`,
    })
    sent_to = '';

    @attribute({
        label: t`Alert Time`,
    })
    created_at = '';

    @attribute({
        label: t`acknowledged`,
    })
    acknowledged = false;

    @attribute({
        label: t`Acknowledged by`,
    })
    acknowledged_by = '';

    @action.bound
    async acknowledge(acknowledgedBy: string): Promise<void> {
        const response = await AlertStore.transportLayer.fetch(`/${encodeURIComponent(this.getId())}/acknowledge`, {
            method: "PATCH",
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                ['alert']: {
                    'acknowledge_by' : acknowledgedBy
                },
                appId: localStorage.getItem('appId')
            })
        });
        await this.store.transportLayer.parseJson(response);
        this.store.getTableData(true);
    }

    constructor() {
        super();
        super.setup();
    }
}

export const AlertStore = AlertModel.store as DataStore<AlertModel>;