import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {computed} from "mobx";

@model({
    transportLayer: "/api/alerting_emails",
    permissionTarget: "AlertingEmail",
    routingInfo: {
        create: '/settings/alerting_emails/create',
        read: '/settings/alerting_emails/:id/edit',
        update: '/settings/alerting_emails/:id/edit'
    }
})
export class AlertingEmailModel extends Model {
    @attribute({
        label: t`Name`,
        validation: yup.string().required(t`Name is a required field`)
    })
    name = '';

    @attribute({
        label: t`Email`,
        validation: yup.string().email().required(t`Email is a required field`)
    })
    email = '';

    @computed
    get displayName(): string {
        return `${this.name} (${this.email})`
    }

    constructor() {
        super();
        super.setup();
    }
}

export const AlertingEmailStore = AlertingEmailModel.store as DataStore<AlertingEmailModel>;
