module ExternalDataCache
  class RxData < ExternalDataCache::ModuleDataCache
    include Singleton

    def module_name
      "rx_data"
    end

    def data_expiry_time
      # Machine data needs to be fresh before every alert executor cycle (2 min interval)
      2.minutes - 10.seconds
    end

    def machine_status_all
      Rails.cache.fetch([self, :machine_states], expires_in: data_expiry_time) do
        fetch("#{machine_endpoint}/status_all")
      end
    end

    def latest_job_states_per_machine
      Rails.cache.fetch([self, :job_states], expires_in: data_expiry_time) do
        fetch("#{machine_endpoint}/last_job_states_per_machine?limit=5")
      end
    end

    private

    def fetch(endpoint)
      begin
        RxModule::Communicator.call_module_method_internal(module_name, endpoint, :get)
      rescue StandardError => e
        Rails.logger.error "[RxData Cache] Failed to retrieve #{endpoint}. Error: #{e}"
        {}
      end
    end

    def machine_endpoint
      "/api/machines/"
    end
  end
end
