module ExternalDataCache
  class RxHub < ExternalDataCache::ModuleDataCache
    include Singleton

    def module_name
      "rx_hub"
    end

    def data_expiry_time
      # Shift and user data is unlikely to change often
      5.minutes
    end

    def shifts
      Rails.cache.fetch([self, :shifts], expires_in: data_expiry_time) do
        begin
          RxModule::Communicator::Shifts.current_shifts[:models]
        rescue StandardError => e
          Rails.logger.error "[RxHub Cache] Failed to get shifts. Error: #{e}"
          []
        end
      end
    end

    def users
      Rails.cache.fetch([self, :users], expires_in: data_expiry_time) do
        begin
          RxModule::Communicator::Hub.picker_users
        rescue StandardError => e
          Rails.logger.error "[RxHub Cache] Failed to get users. Error: #{e}"
          []
        end
      end
    end
  end
end
