class Alert < ApplicationRecord
  belongs_to :alert_rule

  @local_only = true

  def self.ensure_email_enabled
    @local_only = !RxModule::Communicator::Emails.email_enabled?
  end

  def self.local_only?
    @local_only
  end

  def self.target_has_active?(alert_target, rule_id)
    Alert.find_by(target_identifier: alert_target, alert_rule_id: rule_id, acknowledged: false) != nil
  end

  def self.acknowledge_stale
    setting = Setting.instance
    min_count = (setting.acknowledge_alert_after / 60)
    Alert.where(acknowledged: false)
      .where(Alert.arel_table[:created_at].lt(Time.zone.now - min_count.minutes))
      .update_all(acknowledged: true, acknowledged_by: "AUTOMATIC")
  end
end
