class MachineInState < AlertRule
  include TimeFormatter

  def execute
    machine_data = ExternalDataCache::RxData.instance.machine_status_all
    machine_states = trigger_states
    duration_until_alert = trigger_duration

    return if duration_until_alert.nil?

    machine_data.each do |sn, data|
      # If the machine state or duration doesn't match the rule trigger, don't bother checking targets
      next unless machine_states.include? data[:status]
      next unless duration_until_alert <= data[:duration]

      # Machine status passes trigger criterion, check the alert rule target list
      identifiers = [target_id(data[:machine_id])]
      identifiers += data[:groups].map { |id| "g-#{id}" } unless data[:groups].nil?

      send_alert(target_id(data[:machine_id]), identifiers, {sn: sn, data: data})
    end
  end

  def trigger_duration
    resolved_parameters[:trigger_duration]
  end

  def trigger_states
    return [] if resolved_parameters[:trigger_states].nil?
    resolved_parameters[:trigger_states]
  end

  def build_email_data(email_params)
    machine_sn, machine_data = email_params.values
    time = if machine_data[:time].nil?
             "unknown"
           else
             date, time = date_time_string_from_time_string(machine_data[:time])
             "#{time} - #{date}"
           end

    {
      '[machine]' => machine_data[:name] || "",
      '[sn]' => machine_sn.to_s,
      '[state]' => machine_data[:status],
      '[time]' => time
    }
  end
end
