class MachineTimeDeviation < AlertRule
  include TimeFormatter

  def execute
    job_states_per_machine = ExternalDataCache::RxData.instance.latest_job_states_per_machine

    job_states_per_machine.each do |sn, job_states|
      job_states.each do |job_state|
        if (Time.zone.parse(job_state[:time]) - Time.zone.parse(job_state[:created_at])).abs > desync_time
          identifiers = [target_id(job_state[:machine_id])]
          identifiers += job_state[:machine_group_ids].map { |id| "g-#{id}" } unless job_state[:machine_group_ids].nil?

          send_alert(target_id(job_state[:machine_id]), identifiers, {sn: sn, data: job_state})
        end
      end
    end
  end

  def build_email_data(email_params)
    machine_sn, job_state = email_params.values
    job_state_time = if job_state[:time].nil?
                       "unknown"
                     else
                       date, time = date_time_string_from_time_string(job_state[:time])
                       "#{time} - #{date}"
                     end
    date, time = date_time_string_from_time_string(job_state[:created_at])
    server_time =  "#{time} - #{date}"
    {
      '[machine]' => job_state[:name] || "",
      '[sn]' => machine_sn.to_s,
      '[job state time]' => job_state_time,
      '[server_time]' => server_time
    }
  end

  def desync_time
    10.minutes
  end
end