class AddTypeToAlertRules< ActiveRecord::Migration[6.0]

  class MachineAlertRule < ActiveRecord::Base
  end

  class AlertRule < ActiveRecord::Base
  end

  class MachineAlertRuleTarget < ActiveRecord::Base
  end

  def up
    # need to merge machine_alert_rule into alert_rule
    # add type to alert_rule to make it a single table inheritance
    change_table :alert_rules do |t|
      t.column :parameters, :text

      MachineAlertRule.find_each do |machine_rule|
        alert_rule_id = machine_rule.alert_rule_id
        alert_rule = AlertRule.find_by(id: alert_rule_id)
        params = {
          trigger_duration: machine_rule.trigger_duration,
          trigger_states: machine_rule.trigger_states&.split(",")
        }
        alert_rule.update(parameters: params.stringify_keys.to_json)
      end

      t.column :type, :string, default: :MachineInState, null: false
    end

    # need to rename machine_alert_rule_target to alert_rule_target
    add_belongs_to :machine_alert_rule_targets, :alert_rule

    MachineAlertRuleTarget.find_each do |target|
      target.update(alert_rule_id: target.machine_alert_rule_id)
    end

    remove_reference :machine_alert_rule_targets, :machine_alert_rule
    rename_table :machine_alert_rule_targets, :alert_rule_targets


    # Remove unused table after all data extracted from it
    drop_table :machine_alert_rules

    remove_column :alert_rules, :alert_type
  end

  def down
    remove_column :alert_rules, :type
    add_column :alert_rules, :alert_type, :integer, null: false

    create_table :machine_alert_rules do |t|
      t.column :trigger_duration, :integer
      t.column :trigger_states, :string
      t.integer :trigger_type
      t.belongs_to :alert_rule
      t.timestamps
    end

    AlertRule.find_each do |rule|
      params = JSON.parse(rule.parameters).symbolize_keys
      MachineAlertRule.create(trigger_duration: params[:trigger_duration],
                              trigger_states: params[:trigger_states],
                              trigger_type: 0,
                              alert_rule_id: rule.id)
    end

    rename_table :alert_rule_targets, :machine_alert_rule_targets

    add_belongs_to :machine_alert_rule_targets, :machine_alert_rule

    MachineAlertRuleTarget.find_each do |target|
      target.update(machine_alert_rule_id: target.alert_rule_id)
    end

    remove_reference :machine_alert_rule_targets, :alert_rule

    remove_column :alert_rules, :parameters
  end
end
